summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/jabber/libiris/iris/xmpp-core/securestream.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/jabber/libiris/iris/xmpp-core/securestream.cpp')
-rw-r--r--kopete/protocols/jabber/libiris/iris/xmpp-core/securestream.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/kopete/protocols/jabber/libiris/iris/xmpp-core/securestream.cpp b/kopete/protocols/jabber/libiris/iris/xmpp-core/securestream.cpp
index 55555f04..fdcd57c1 100644
--- a/kopete/protocols/jabber/libiris/iris/xmpp-core/securestream.cpp
+++ b/kopete/protocols/jabber/libiris/iris/xmpp-core/securestream.cpp
@@ -22,7 +22,7 @@
Note: SecureStream depends on the underlying security layers to signal
plain-to-encrypted results immediately (as opposed to waiting for the
event loop) so that the user cannot add/remove security layers during
- this conversion moment. QCA::TLS and QCA::SASL behave as expected,
+ this conversion moment. TQCA::TLS and TQCA::SASL behave as expected,
but future layers might not.
*/
@@ -117,8 +117,8 @@ public:
enum { TLS, SASL, TLSH };
int type;
union {
- QCA::TLS *tls;
- QCA::SASL *sasl;
+ TQCA::TLS *tls;
+ TQCA::SASL *sasl;
#ifdef USE_TLSHANDLER
XMPP::TLSHandler *tlsHandler;
#endif
@@ -127,7 +127,7 @@ public:
bool tls_done;
int prebytes;
- SecureLayer(QCA::TLS *t)
+ SecureLayer(TQCA::TLS *t)
{
type = TLS;
p.tls = t;
@@ -139,7 +139,7 @@ public:
connect(p.tls, TQT_SIGNAL(error(int)), TQT_SLOT(tls_error(int)));
}
- SecureLayer(QCA::SASL *s)
+ SecureLayer(TQCA::SASL *s)
{
type = SASL;
p.sasl = s;
@@ -381,7 +381,7 @@ int SecureStream::calcPrebytes() const
return (d->pending - x);
}
-void SecureStream::startTLSClient(QCA::TLS *t, const TQByteArray &spare)
+void SecureStream::startTLSClient(TQCA::TLS *t, const TQByteArray &spare)
{
if(!d->active || d->topInProgress || d->haveTLS())
return;
@@ -395,7 +395,7 @@ void SecureStream::startTLSClient(QCA::TLS *t, const TQByteArray &spare)
insertData(spare);
}
-void SecureStream::startTLSServer(QCA::TLS *t, const TQByteArray &spare)
+void SecureStream::startTLSServer(TQCA::TLS *t, const TQByteArray &spare)
{
if(!d->active || d->topInProgress || d->haveTLS())
return;
@@ -409,7 +409,7 @@ void SecureStream::startTLSServer(QCA::TLS *t, const TQByteArray &spare)
insertData(spare);
}
-void SecureStream::setLayerSASL(QCA::SASL *sasl, const TQByteArray &spare)
+void SecureStream::setLayerSASL(TQCA::SASL *sasl, const TQByteArray &spare)
{
if(!d->active || d->topInProgress || d->haveSASL())
return;
@@ -434,7 +434,7 @@ void SecureStream::startTLSClient(XMPP::TLSHandler *t, const TQString &server, c
d->layers.append(s);
d->topInProgress = true;
// unlike QCA::TLS, XMPP::TLSHandler has no return value
s->p.tlsHandler->startClient(server);
insertData(spare);
@@ -434,7 +434,7 @@ void SecureStream::startTLSClient(XMPP::TLSHandler *t, const TQString &server, c
d->layers.append(s);
d->topInProgress = true;
- // unlike QCA::TLS, XMPP::TLSHandler has no return value
+ // unlike TQCA::TLS, XMPP::TLSHandler has no return value
s->p.tlsHandler->startClient(server);
insertData(spare);